@@ -227,7 +227,7 @@ sub run
             print STDERR ">> $in\n"
               if $debug;
             # wait for all input to go
-            $h->pump while length $in;
+            $h->pump_nb while length $in;
         }
     }
 
